mix tz_world.update (TzWorld v1.4.2)

Downloads and installs the latest Timezone GeoJSON data.

Argument

  • --include-oceans Will include the geojson for oceans in the downloaded data.

  • --force will force an update even if the data is current. This can be used to force downloading data including (or not including) time zone data for the oceans.

Summary

Functions

run(args)

Callback implementation for Mix.Task.run/1.

update(include_oceans?, force_update?, trace?)